@@ -1,15 +1,13 @@
 use super::Optimizer;
-use crate::compress::util::negate;
-use crate::util::make_bool;
-use crate::util::ValueExt;
+use crate::{
+    compress::util::negate,
+    util::{make_bool, ValueExt},
+};
 use swc_atoms::js_word;
 use swc_common::EqIgnoreSpan;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
-use swc_ecma_utils::ident::IdentLike;
-use swc_ecma_utils::ExprExt;
-use swc_ecma_utils::Type;
-use swc_ecma_utils::Value;
+use swc_ecma_utils::{ident::IdentLike, ExprExt, Type, Value};
 use Value::Known;
 
 impl Optimizer<'_> {
