@@ -12,7 +12,7 @@ pub(super) struct Ctx {
 
     pub is_callee: bool,
 
-    pub in_try_block: bool,
+    pub _in_try_block: bool,
 
     pub is_lhs_of_assign: bool,
 
