@@ -7,7 +7,7 @@ use std::time::Instant;
 use swc_common::{Mark, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::ident::IdentLike;
-use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith, VisitWith};
+use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith, VisitWith};
 
 mod analyzer;
 
@@ -15,22 +15,18 @@ mod analyzer;
 ///
 /// Requires [swc_common::GLOBALS].
 pub fn optimize_hygiene(m: &mut Module, top_level_mark: Mark) {
-    let data = analyze(&*m, None);
-    m.visit_mut_with(&mut hygiene_optimizer(data, top_level_mark))
+    m.visit_mut_with(&mut hygiene_optimizer(top_level_mark))
 }
 
 /// Create a hygiene optimizer.
 ///
 /// Hygiene optimizer removes span hygiene without renaming if it's ok to do so.
-pub(crate) fn hygiene_optimizer(
-    data: ProgramData,
-    top_level_mark: Mark,
-) -> impl 'static + VisitMut {
-    Optimizer {
-        data,
+pub fn hygiene_optimizer(top_level_mark: Mark) -> impl 'static + VisitMut + Fold {
+    as_folder(Optimizer {
+        data: Default::default(),
         hygiene: Default::default(),
         top_level_mark,
-    }
+    })
 }
 
 struct Optimizer {
@@ -70,6 +66,38 @@ impl VisitMut for Optimizer {
         log::info!("hygiene: Analyzing span hygiene");
         let start = now();
 
+        self.data = analyze(&*n, None);
+
+        let mut analyzer = HygieneAnalyzer {
+            data: &self.data,
+            hygiene: Default::default(),
+            top_level_mark: self.top_level_mark,
+            cur_scope: None,
+        };
+        n.visit_with(&Invalid { span: DUMMY_SP }, &mut analyzer);
+        self.hygiene = analyzer.hygiene;
+
+        if let Some(start) = start {
+            let end = Instant::now();
+            log::info!("hygiene: Span hygiene analysis took {:?}", end - start);
+        }
+        let start = now();
+
+        log::info!("hygiene: Optimizing span hygiene");
+        n.visit_mut_children_with(self);
+
+        if let Some(start) = start {
+            let end = Instant::now();
+            log::info!("hygiene: Span hygiene optimiation took {:?}", end - start);
+        }
+    }
+
+    fn visit_mut_script(&mut self, n: &mut Script) {
+        log::info!("hygiene: Analyzing span hygiene");
+        let start = now();
+
+        self.data = analyze(&*n, None);
+
         let mut analyzer = HygieneAnalyzer {
             data: &self.data,
             hygiene: Default::default(),
