@@ -31,6 +31,8 @@ pub trait MoudleItemExt: StmtLike + ModuleItemLike + From<Stmt> {
     }
 
     fn into_module_decl(self) -> Result<ModuleDecl, Stmt>;
+
+    fn as_stmt_mut(&mut self) -> Option<&mut Stmt>;
 }
 
 impl MoudleItemExt for Stmt {
@@ -45,6 +47,10 @@ impl MoudleItemExt for Stmt {
     fn into_module_decl(self) -> Result<ModuleDecl, Stmt> {
         Err(self)
     }
+
+    fn as_stmt_mut(&mut self) -> Option<&mut Stmt> {
+        Some(self)
+    }
 }
 
 impl MoudleItemExt for ModuleItem {
@@ -65,6 +71,13 @@ impl MoudleItemExt for ModuleItem {
             ModuleItem::Stmt(v) => Err(v),
         }
     }
+
+    fn as_stmt_mut(&mut self) -> Option<&mut Stmt> {
+        match self {
+            ModuleItem::ModuleDecl(_) => None,
+            ModuleItem::Stmt(s) => Some(s),
+        }
+    }
 }
 
 ///
